#include <gtk/gtk.h>
#include "vncviewer.h"

#define MINI_WIND_WIDTH 180
#define MINI_WIND_HEIGHT 30
extern struct client_cb client_CB;
extern char answer;
extern ServerAdv serveradv;

gboolean
on_drawingarea_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea_expose_event           (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_dialog_IDinput_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_IDinput_entry_changed       (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_dialog_IDinput_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_IDinput_buttonCancel_clicked (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_wait_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_wait_buttonStop_clicked      (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_recvAdv_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_recvAdv_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_recvAdv_buttonCancel_clicked (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_dialog_inputmiss_delete_event       (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_inputmiss_buttonOK_clicked   (GtkButton       *button,
                                        gpointer         user_data);


void
on_dialog_IDinput_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_recvAdv_buttonOK_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_inputmiss_buttonOK_clicked   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_drawingarea1_configure_event        (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_drawingarea1_expose_event           (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_lock_screen_configure_event    (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_lock_screen_expose_event       (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_mini_window_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_mini_drawingarea_configure_event    (GtkWidget       *widget,
                                        GdkEventConfigure *event,
                                        gpointer         user_data);

gboolean
on_mini_drawingarea_expose_event       (GtkWidget       *widget,
                                        GdkEventExpose  *event,
                                        gpointer         user_data);

gboolean
on_dialog_exit_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_dialog_exit_buttonOK_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_dialog_exit_buttonCancel_clicked    (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_drawing_window_delete_event         (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);


void
on_dialog_IDinput_entry_editing_done   (GtkCellEditable *celleditable,
                                        gpointer         user_data);

gboolean
on_entry_focus_in_event                (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

gboolean
on_entry_focus_out_event               (GtkWidget       *widget,
                                        GdkEventFocus   *event,
                                        gpointer         user_data);

void
on_entry_realize                       (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_entry_unrealize                     (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_dialog_IDinput_entry_changed        (GtkEditable     *editable,
                                        gpointer         user_data);
